import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { PressReleaseCmsRepository } from "./press-release-cms.repository";
import { UpdatePressReleaseCmsDto } from "./dto/update-press-release-cms.dto";
import { PressReleaseCms } from "./entities/press-release-cms.entity";

@Injectable()
export class PressReleaseCmsService {
    constructor(
      @InjectRepository(PressReleaseCmsRepository)
      private readonly repository: PressReleaseCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdatePressReleaseCmsDto,
      files: {
          bannerImage: UploadedMulterFileI
      }
    ): Promise<PressReleaseCms | Error> {
        if (files && files.bannerImage) {
            const image: any = await this.doSpaceService.uploadFile(files.bannerImage[0], "PressReleaseCms/");
            dto.bannerImage = image;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PressReleaseCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}