import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateOrderServiceDto } from "./dto/create-order-service.dto";
import { OrderService } from "./entities/order-service.entity";

@EntityRepository(OrderService)
export class OrderServiceRepository extends Repository<OrderService> {
    async createEntity(dto: CreateOrderServiceDto): Promise<OrderService | Error> {
        try {
            const {
                orderNumber,
                email
            } = dto;
            const entity = this.create({
                orderNumber,
                email
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<OrderService | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<any | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(OrderService)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}